# -----------------------------------------
#
#                 NetMath
#
# -----------------------------------------

Netmath is a simple package that has a NetMath class. This class holds methods used with IP addresses to make subnetting easier. 
